gatenlp.serialization.default module — GATE NLP library (gatenlp) documentation

# gatenlp.serialization.default module

class `gatenlp.serialization.default.` `JsonSerializer`

  Bases: `object`

  static `load`(clazz, from_file=None, from_mem=None, offset_mapper=None, **kwargs)
  static `save`(clazz, inst, to_file=None, to_mem=None, offset_type=None, offset_mapper=None, **kwargs)

class `gatenlp.serialization.default.` `MsgPackSerializer`

  Bases: `object`

  static `document2stream`(doc: gatenlp.document.Document, stream)
  static `load`(clazz, from_file=None, from_mem=None, offset_mapper=None, **kwargs)
  static `save`(clazz, inst, to_file=None, to_mem=None, offset_type=None, offset_mapper=None, **kwargs)
  static `stream2document`(stream)